@@ -1,9 +1,9 @@
 package App::VivaldiUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-19'; # DATE
+our $DATE = '2020-06-13'; # DATE
 our $DIST = 'App-VivaldiUtils'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -53,6 +53,18 @@ sub unpause_vivaldi {
     App::BrowserUtils::_do_browser('unpause', 'vivaldi', @_);
 }
 
+$SPEC{vivaldi_has_processes} = {
+    v => 1.1,
+    summary => "Check whether Vivaldi has processes",
+    args => {
+        %App::BrowserUtils::args_common,
+        %App::BrowserUtils::argopt_quiet,
+    },
+};
+sub vivaldi_has_processes {
+    App::BrowserUtils::_do_browser('has_processes', 'vivaldi', @_);
+}
+
 $SPEC{vivaldi_is_paused} = {
     v => 1.1,
     summary => "Check whether Vivaldi is paused",
@@ -101,6 +113,36 @@ sub terminate_vivaldi {
     App::BrowserUtils::_do_browser('terminate', 'vivaldi', @_);
 }
 
+$SPEC{restart_vivaldi} = {
+    v => 1.1,
+    summary => "Restart Vivaldi",
+    args => {
+        %App::BrowserUtils::argopt_vivaldi_cmd,
+        %App::BrowserUtils::argopt_quiet,
+    },
+    features => {
+        dry_run => 1,
+    },
+};
+sub restart_vivaldi {
+    App::BrowserUtils::restart_browsers(@_, restart_vivaldi=>1);
+}
+
+$SPEC{start_vivaldi} = {
+    v => 1.1,
+    summary => "Start Vivaldi if not already started",
+    args => {
+        %App::BrowserUtils::argopt_vivaldi_cmd,
+        %App::BrowserUtils::argopt_quiet,
+    },
+    features => {
+        dry_run => 1,
+    },
+};
+sub start_vivaldi {
+    App::BrowserUtils::start_browsers(@_, start_vivaldi=>1);
+}
+
 1;
 # ABSTRACT: Utilities related to the Vivaldi browser
 
@@ -116,7 +158,7 @@ App::VivaldiUtils - Utilities related to the Vivaldi browser
 
 =head1 VERSION
 
-This document describes version 0.006 of App::VivaldiUtils (from Perl distribution App-VivaldiUtils), released on 2020-04-19.
+This document describes version 0.007 of App::VivaldiUtils (from Perl distribution App-VivaldiUtils), released on 2020-06-13.
 
 =head1 SYNOPSIS
 
@@ -134,10 +176,16 @@ This distribution includes several utilities related to the Vivaldi browser:
 
 =item * L<ps-vivaldi>
 
+=item * L<restart-vivaldi>
+
+=item * L<start-vivaldi>
+
 =item * L<terminate-vivaldi>
 
 =item * L<unpause-vivaldi>
 
+=item * L<vivaldi-has-processes>
+
 =item * L<vivaldi-is-paused>
 
 =item * L<vivaldi-is-running>
@@ -159,7 +207,7 @@ A modern browser now runs complex web pages and applications. Despite browser's
 power management feature, these pages/tabs on the browser often still eat
 considerable CPU cycles even though they only run in the background. Stopping
 (kill -STOP) the browser processes is a simple and effective way to stop CPU
-eating on Unix. It can be performed whenever you are not using your browsers for
+eating on Unix. It can be performed whenever you are not using your browser for
 a little while, e.g. when you are typing on an editor or watching a movie. When
 you want to use your browser again, simply unpause it.
 
@@ -223,6 +271,100 @@ Return value:  (any)
 
 
 
+=head2 restart_vivaldi
+
+Usage:
+
+ restart_vivaldi(%args) -> [status, msg, payload, meta]
+
+Restart Vivaldi.
+
+This function is not exported.
+
+This function supports dry-run operation.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<quiet> => I<true>
+
+=item * B<vivaldi_cmd> => I<array[str]|str> (default: "vivaldi")
+
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-dry_run> => I<bool>
+
+Pass -dry_run=E<gt>1 to enable simulation mode.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
+=head2 start_vivaldi
+
+Usage:
+
+ start_vivaldi(%args) -> [status, msg, payload, meta]
+
+Start Vivaldi if not already started.
+
+This function is not exported.
+
+This function supports dry-run operation.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<quiet> => I<true>
+
+=item * B<vivaldi_cmd> => I<array[str]|str> (default: "vivaldi")
+
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-dry_run> => I<bool>
+
+Pass -dry_run=E<gt>1 to enable simulation mode.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 terminate_vivaldi
 
 Usage:
@@ -291,6 +433,42 @@ Return value:  (any)
 
 
 
+=head2 vivaldi_has_processes
+
+Usage:
+
+ vivaldi_has_processes(%args) -> [status, msg, payload, meta]
+
+Check whether Vivaldi has processes.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<quiet> => I<true>
+
+=item * B<users> => I<array[unix::local_uid]>
+
+Kill browser processes that belong to certain user(s) only.
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 vivaldi_is_paused
 
 Usage:
